@@ -1,5 +1,5 @@
 import os
-import importlib
+import importlib.util
 import re
 
 def extract_function(urls_content, url):
@@ -9,26 +9,36 @@ def extract_function(urls_content, url):
         return False
 
     urls = eval(match.group(1))
-    print(urls)
     for u in urls:
         if u[0] == url:
             return u[1]
     return False
 
-def get_view(url, project_name):
-    views_path = os.path.join(project_name, "urls.py")
-    if not os.path.exists(views_path):
+def change_path_format(path):
+    components = path.split(os.path.sep)
+
+    dot_string = ".".join(components)
+    return dot_string
+
+def get_view(url, project_path):
+    urls_path = os.path.join(project_path, "urls.py")
+
+    if not os.path.exists(urls_path):
         return False
-    
-    with open(views_path, "r") as f:
+
+    with open(urls_path, "r") as f:
         contents = f.read()
+
     class_name = extract_function(contents, url)
 
-    views_module = importlib.import_module("{}.views".format(project_name))
-    view_func = getattr(views_module, class_name)
-    
-    return view_func()
+    views_path = os.path.join(project_path, "views.py")
+    spec = importlib.util.spec_from_file_location("views", str(views_path))
+    views_module = importlib.util.module_from_spec(spec)
+    spec.loader.exec_module(views_module)
 
+    view_func = getattr(views_module, class_name)
+
+    return view_func()
 
 def handle_request(project_name, path, method, form):
     # Handle the root route
@@ -38,4 +48,3 @@ def handle_request(project_name, path, method, form):
         return "HTTP/1.1 404 Not Found\nContent-Type: text/plain\nContent-Length: 9\n\nNot Found"
 
     return "HTTP/1.1 200 OK\nContent-Type: text/html\nContent-Length: {}\n\n{}".format(len(response_body), response_body)
-
